==> etherape_0.8.2.orig.tar.gz: etherape-0.8.2/src/util.h <==
/* util.h
 * Utility definitions
 *
 * $Id: util.h,v 1.2 2000/03/07 23:51:25 toledo Exp $
 *
 * Ethereal - Network traffic analyzer
 * By Gerald Combs <gerald@zing.org>
 * Copyright 1998 Gerald Combs
 *
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef __UTIL_H__
#define __UTIL_H__

#ifdef __cplusplus
extern "C"
{
#endif				/* __cplusplus */

/*
 * Given a pathname, return the last component.
 */
  char *get_basename (char *);

/*
 * Given a pathname, return a string containing everything but the
 * last component.  NOTE: this overwrites the pathname handed into
 * it....
 */
  char *get_dirname (char *);

  int create_tempfile (char *, int, const char *);

/* Returns the user's home directory, via the HOME environment
 * variable, or a default directory if HOME is not set */
  const char *get_home_dir (void);

#ifdef HAVE_LIBPCAP

  GList *get_interface_list (int *err, char *err_str);

/* Error values from "get_interface_list()". */
#define	CANT_GET_INTERFACE_LIST	0	/* error getting list */
#define	NO_INTERFACES_FOUND	1	/* list is empty */

  void free_interface_list (GList * if_list);

#endif

#ifdef __cplusplus
}
#endif				/* __cplusplus */

#endif				/* __UTIL_H__ */

==> etherape_0.9.7.orig.tar.gz: etherape-0.9.7/src/util.h <==
/* util.h
 * Utility definitions
 *
 * $Id: util.h,v 1.6 2006/04/29 07:58:35 bchiara Exp $
 *
 * Ethereal - Network traffic analyzer
 * By Gerald Combs <gerald@zing.org>
 * Copyright 1998 Gerald Combs
 *
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef __UTIL_H__
#define __UTIL_H__

#ifdef __cplusplus
extern "C"
{
#endif				/* __cplusplus */

/* Returns the user's home directory, via the HOME environment
 * variable, or a default directory if HOME is not set */
  const char *get_home_dir (void);

  /* gets a list containing the names of available interfaces. Returns NULL 
   * if there is an error, putting also an error message into err_str.
   * The returned list MUST be freed with interface_list_free() */
  GList *interface_list_create(GString *err_str);
  void interface_list_free(GList * if_list);

  char *safe_strncpy (char *dst, const char *src, size_t maxlen);
  char *safe_strncat (char *dst, const char *src, size_t maxlen);

#ifdef __cplusplus
}
#endif				/* __cplusplus */


#endif				/* __UTIL_H__ */
